@@ -20,13 +20,19 @@
 
 // 27.4.3 fpos
 
-// { dg-do run { xfail *-*-* } }
-
-#include <typeinfo>
-#include <limits>
 #include <iterator>
 #include <testsuite_hooks.h>
 
+class Fred
+{
+public:
+  Fred(bool)
+  { }
+};
+
+void barney(Fred)
+{ }
+
 // libstdc++/14320
 void test01()
 {
@@ -34,24 +40,9 @@ void test01()
   bool test __attribute__((unused)) = true;
 
   typedef istreambuf_iterator<char>::difference_type Distance;
-
-  bool found = false;
-  if (typeid(Distance) == typeid(long int))
-    found = true;
-  if (typeid(Distance) == typeid(int))
-    found = true;
-  if (typeid(Distance) == typeid(short int))
-    found = true;
-  if (typeid(Distance) == typeid(signed char))
-    found = true;
-  if (numeric_limits<char>::is_signed &&
-      typeid(Distance) == typeid(char))
-    found = true;
-  if (numeric_limits<wchar_t>::is_signed &&
-      typeid(Distance) == typeid(wchar_t))
-    found = true;
   
-  VERIFY( found );
+  Distance d = 0;
+  barney(d);
 }
 
 int main()
